.. image:: https://github.com/dfm/python-fsps/workflows/Tests/badge.svg
  :target: https://github.com/dfm/python-fsps/actions?query=workflow%3ATests

**Read the documentation:**
`dfm.io/python-fsps <https://dfm.io/python-fsps>`_

If you use this code, follow the citation requirements `on the FSPS
homepage <https://github.com/cconroy20/fsps>`_ and reference
these Python bindings:

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.591505.svg
   :target: https://doi.org/10.5281/zenodo.591505
